@@ -11,7 +11,7 @@ class _SoftDeleteManager(models.Manager):
         return _SoftDeleteQuerySet(self.model, using=self._db).filter(is_deleted=False)
 
 
-class SoftDeleteMixin(models.Model):
+class SoftDeleteMixin:
     is_deleted = models.BooleanField(default=False, null=False, blank=True, db_index=True)
     objects = _SoftDeleteManager()
 
